Module GetSettingSafely
    ' Get a Boolean.
    Public Function GetSettingBoolean(ByVal AppName As String, ByVal Section As String, ByVal Key As String, ByVal default_value As Boolean) As Boolean
        Try
            Return CBool(GetSetting(AppName, Section, Key, default_value))
        Catch ex As Exception
            Return default_value
        End Try
    End Function

    ' Get a Boolean with optional extra values.
    Public Function GetSettingBooleanExtras(ByVal AppName As String, ByVal Section As String, ByVal Key As String, ByVal default_value As Boolean, Optional ByVal true_values() As String = Nothing, Optional ByVal false_values() As String = Nothing) As Boolean
        Dim txt As String = GetSetting(AppName, Section, Key, default_value)

        ' Check for alternate values.
        If true_values IsNot Nothing Then
            For Each true_value As String In true_values
                If txt.ToLower() = true_value.ToLower() Then Return True
            Next true_value
        End If
        If false_values IsNot Nothing Then
            For Each false_value As String In false_values
                If txt.ToLower() = false_value.ToLower() Then Return False
            Next false_value
        End If

        ' Use what we got from the Registry.
        Try
            Return CBool(GetSetting(AppName, Section, Key, default_value))
        Catch ex As Exception
            Return default_value
        End Try
    End Function

    ' Get an Integer.
    Public Function GetSettingInteger(ByVal AppName As String, ByVal Section As String, ByVal Key As String, ByVal default_value As Integer) As Integer
        Try
            Return CInt(GetSetting(AppName, Section, Key, default_value))
        Catch ex As Exception
            Return default_value
        End Try
    End Function

    ' Get a String.
    Public Function GetSettingString(ByVal AppName As String, ByVal Section As String, ByVal Key As String, ByVal default_value As String) As String
        Try
            Return CStr(GetSetting(AppName, Section, Key, default_value))
        Catch ex As Exception
            Return default_value
        End Try
    End Function

    ' Get a Long.
    Public Function GetSettingLong(ByVal AppName As String, ByVal Section As String, ByVal Key As String, ByVal default_value As Long) As Long
        Try
            Return CLng(GetSetting(AppName, Section, Key, default_value))
        Catch ex As Exception
            Return default_value
        End Try
    End Function

    ' Get a Date.
    Public Function GetSettingDate(ByVal AppName As String, ByVal Section As String, ByVal Key As String, ByVal default_value As Date) As Date
        Try
            Return CDate(GetSetting(AppName, Section, Key, default_value))
        Catch ex As Exception
            Return default_value
        End Try
    End Function
End Module
